=======
Credits
=======

Development Lead
----------------

* Diego Navarro <diego@feverup.com>

Contributors
------------

* Pablo Camino <pablo.camino@feverup.com>
* Marcos Hernández <marcos.hernandez@feverup.com>
* Sergi Almacellas Abellana <sergi@koolpi.com>
* Luis Pintado <luis.pintado@feverup.com>
* Miguel Gonzalez <miguel.gonzalez@feverup.com>
* Gerardo Parra <gerardo.parra@feverup.com>
